{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Tcsh.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/tcsh.xml and 'make bootstrap'.
module Skylighting.Syntax.Tcsh (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Tcsh.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btcsh.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbuiltins\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abindkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbuiltins\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbye\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdirs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKechotc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfiletest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTglob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhashstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjobs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTls-F\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amigrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnewgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnohup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnotify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKonintr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprintenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrehash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsched\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsettc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtelltc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQumask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nuncomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunhash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwatchlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhich\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbuiltins_var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsetenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funixcommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funixcommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ArithmeticCondition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ArithmeticCondition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ArithmeticCondition\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r[=!]~|[=!><]=\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f!%&*+-/<>^|~\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindOthers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL(\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindOthers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[\\w:,+_./-]+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL)\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL[\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL=\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCmdSetEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCmdSetEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\b[A-Za-z_][A-Za-z0-9_]*\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\t \DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t[^`](?=`)\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElseIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElseIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ArithmeticCondition\NUL[\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM(\\s\\]|^\\])(?=($|[\\s;|&]))\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprSubParen\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindTests\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprSubParen\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH))\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprSubParen\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprSubParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprSubParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprSubParen\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFindAll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFindAll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindCommands\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindOthers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindCommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindCommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\SOH((\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4(^\\[|\\s\\[)(?=($|\\s))\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\{(?=($|\\s))\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\bif(?![\\w$+-])\SOH\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIf\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\belse\\s+if(?![\\w$+-])\SOH\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElseIf\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\belse(?![\\w$+-])\SOH\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\bendif(?![\\w$+-])\SOH\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\bswitch(?![\\w$+-])\SOH\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSwitch\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\b(foreach|while)(?![\\w$+-])\SOH\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\bend(?![\\w$+-])\SOH\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL/-[A-Za-z0-9][A-Za-z0-9_]*|--[a-z][A-Za-z0-9_-]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\b@\\s\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCmdSetEnv\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX:()\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\t\n !&()*+,/;<=>?\\`|~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\t\n !&()*+,/;<=>?\\`|~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abindkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbuiltins\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbye\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdirs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKechotc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfiletest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTglob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhashstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjobs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTls-F\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amigrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnewgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnohup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnotify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKonintr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprintenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrehash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsched\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsettc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtelltc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQumask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nuncomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunhash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwatchlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhich\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\t\n !&()*+,/;<=>?\\`|~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHj\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aaclocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXapm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bapmsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aapropos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aarecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTas86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautoconf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nautoheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautomake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQb2sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbasename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbison\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abunzip2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzip2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbzip2recover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXc++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acd-read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcdda2wav\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncdparanoia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdrdao\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcdrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchcon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchroot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcksum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclang++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXco\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcomm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcpio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acrontab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdcop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdeallocvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdiff3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdircolors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdirectomatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adirname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmesg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdnsdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdumpkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfbset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfgconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKflex++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfuser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXg++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetkeycodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agettext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngettextize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgimp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgimp-remote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgimptool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgocr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgzexe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahexdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhostid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhostname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiconv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQigawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainstall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkbd_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akbdrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akdialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akillall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlastb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTld86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXldd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadunimap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blockfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlsattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlsmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlsmod.old\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlynx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlzma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blzmainfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amapscrn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmd5sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmesg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmkfifo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmknod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmktemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnamei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnano\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anetstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnisdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnm86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnohup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopenvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpasswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaste\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apathchk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpcregrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpcretest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTperl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKperror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpgawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpidof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpinky\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprintenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprocmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprune\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bps2ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aps2epsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aps2frag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKps2pdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQps2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsbook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsnup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsresize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstops\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXptx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrbash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brealpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nresizecons\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trun-parts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKruncon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXscp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetkeycodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetleds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetmetamode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetserial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetterm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asha1sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha224sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha256sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha384sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha512sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashowkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQskill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKslogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTssed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assh-add\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tssh-agent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nssh-keygen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vssh-keyscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstdbuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsudo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsuidperl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsvn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtee\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btempfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atimeout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtouch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKumount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\runicode_start\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funicode_stop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuniq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlzma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bupdatedb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKuptime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\butmpdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auuidgen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalgrind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXvi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXwc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhatis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awhereis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhich\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhoami\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxargs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxdg-open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxhost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmodmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXyes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fypdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTznew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azsoelim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\t\n !&()*+,/;<=>?\\`|~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsetenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r(<<?|>>?&?!?)\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t([|&])\\1?\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#[A-Za-z_:][A-Za-z0-9_:#%@-]*\\s*\\(\\)\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n[\\s;](?=#)\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindCommentsBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindCommentsBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n[\\s;](?=#)\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindOthers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindOthers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindOthers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\\\\[;\"\\\\'$`{}()|&<>* ]\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULF([\\w_@.%*?+-]|\\\\ )*(?=/)|~\\w*|/([\\w_@.%*?+-]|\\\\ )*(?=([\\s/):;$`'\"]|$))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\SOH$'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\SOH$\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\$[A-Za-z_][A-Za-z0-9_]*\\[\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\\$([A-Za-z_][A-Za-z0-9_]*)|\\$[*@#?$!_0-9-]|\\$\\{[*@#?$!_0-9-]\\}|\\$\\{#[A-Za-z_][A-Za-z0-9_]*\\}|\\$\\{![A-Za-z_][A-Za-z0-9_]*\\*?\\}\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL6\\$\\{[A-Za-z_][A-Za-z0-9_]*|\\$\\{[*@#?$!_0-9-](?=[:#%/])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarBrace\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$((\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubstBackq\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\\\[`$\\\\]\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindTests\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindTests\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULY-[rwxXeozsfdlbcpSugktRLDIFNZ](?=\\s)|-[AMCUG]:?(?=\\s)|-P[0-7]{,3}:?(?=\\s)|[=!][~=]|[*><!~]\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\\s+[A-Za-z_:][A-Za-z0-9_:#%@-]*(\\s*\\(\\))?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFindAll\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ArithmeticCondition\NUL[\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFindAll\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\\\[`\"\\\\$\\n]\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL3\\\\[abefnrtv\\\\']|\\\\([0-7]{1,3}|x[A-Fa-f0-9]{1,2}|c.)\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFindAll\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL]\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindOthers\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubstBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubstBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindCommentsBackq\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindCommands\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindOthers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSwitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSwitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\scase\\b\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSwitchCase\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\sdefault\\b\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSwitchDefault\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\bendsw(?=$|[\\s;)])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSwitchCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSwitchCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSwitchExpr\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSwitchDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSwitchDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSwitchExpr\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSwitchExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSwitchExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\sbreaksw\\b\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\scase\\b\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFindAll\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL[\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindSubstitutions\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#-[A-Za-z0-9]+|--[a-z][A-Za-z0-9_-]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\b[A-Za-z_][A-Za-z0-9_]*\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL=\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindMost\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[^]})|;`&><]\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL0Matthew Woehlke (mw_triad@users.sourceforge.net)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.csh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.tcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcsh.cshrc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcsh.login\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.tcshrc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.cshrc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.login\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart"
